@@ -1,4 +1,4 @@
-//  $Id: badguy.cpp,v 1.68 2004/05/08 23:46:43 rmcruz Exp $
+//  $Id: badguy.cpp,v 1.68.2.2 2004/08/03 18:47:15 rmcruz Exp $
 // 
 //  SuperTux
 //  Copyright (C) 2000 Bill Kendrick <bill@newbreedsoftware.com>
@@ -288,12 +288,18 @@ BadGuy::check_horizontal_bump(bool checkcliff)
     float halfheight = base.height / 2;
     if (dir == LEFT && issolid( base.x, (int) base.y + halfheight))
     {
+        if (kind == BAD_MRICEBLOCK && mode == KICK)
+            World::current()->trybreakbrick(base.x, base.y + halfheight, false, dir);
+
         dir = RIGHT;
         physic.set_velocity(-physic.get_velocity_x(), physic.get_velocity_y());
         return;
     }
     if (dir == RIGHT && issolid( base.x + base.width, (int)base.y + halfheight))
     {
+        if (kind == BAD_MRICEBLOCK && mode == KICK)
+            World::current()->trybreakbrick(base.x + base.width, (int) base.y + halfheight, false, dir);
+         
         dir = LEFT;
         physic.set_velocity(-physic.get_velocity_x(), physic.get_velocity_y());
         return;
