@@ -1,4 +1,4 @@
-//  $Id: level.cpp,v 1.68 2004/05/10 19:06:02 tobgle Exp $
+//  $Id: level.cpp,v 1.68.2.4 2004/07/27 16:43:23 rmcruz Exp $
 // 
 //  SuperTux
 //  Copyright (C) 2004 SuperTux Development Team, see AUTHORS for details
@@ -480,6 +480,14 @@ Level::load(const std::string& filename)
   int j = 0;
   for(vector<int>::iterator it = ia_tm.begin(); it != ia_tm.end(); ++it, ++i)
     {
+      if(j >= 15)
+        {
+        std::cerr << "Warning: Level higher than 15 interactive tiles."
+                     "Ignoring by cutting tiles.\n"
+                     "The level might not be finishable anymore!\n";
+        break;
+        }
+
       ia_tiles[j][i] = (*it);
       if(i == width - 1)
         {
@@ -491,6 +499,12 @@ Level::load(const std::string& filename)
   i = j = 0;
   for(vector<int>::iterator it = bg_tm.begin(); it != bg_tm.end(); ++it, ++i)
     {
+      if(j >= 15)
+        {
+        std::cerr << "Warning: Level higher than 15 background tiles."
+                     "Ignoring by cutting tiles.\n";
+        break;
+        }
 
       bg_tiles[j][i] = (*it);
       if(i == width - 1)
@@ -503,6 +517,12 @@ Level::load(const std::string& filename)
   i = j = 0;
   for(vector<int>::iterator it = fg_tm.begin(); it != fg_tm.end(); ++it, ++i)
     {
+      if(j >= 15)
+        {
+        std::cerr << "Warning: Level higher than 15 foreground tiles."
+                     "Ignoring by cutting tiles.\n";
+        break;
+        }
 
       fg_tiles[j][i] = (*it);
       if(i == width - 1)
