@@ -1,4 +1,4 @@
-//  $Id: leveleditor.cpp,v 1.109 2004/05/10 21:59:25 tobgle Exp $
+//  $Id: leveleditor.cpp,v 1.109.2.2 2004/07/26 13:56:08 rmcruz Exp $
 //
 //  SuperTux
 //  Copyright (C) 2003 Ricardo Cruz <rick2@aeiou.pt>
@@ -212,8 +212,8 @@ int leveleditor(char* filename)
       /* making events results to be in order */
       if(pos_x < 0)
         pos_x = 0;
-      if(pos_x > (le_world->get_level()->width * 32) - screen->w)
-        pos_x = (le_world->get_level()->width * 32) - screen->w;
+      if(pos_x > (le_world->get_level()->width * 32 + 2*32) - screen->w)
+        pos_x = (le_world->get_level()->width * 32 +2*32) - screen->w;
 
       /* draw the level */
       le_drawlevel();
@@ -780,10 +780,10 @@ void le_drawminimap()
 
   fillrect(left_offset, 0, le_world->get_level()->width*mini_tile_width, 15*4, 200, 200, 200, 128);
 
-  fillrect(left_offset + (pos_x/32)*mini_tile_width, 0, 19*mini_tile_width, 2, 200, 200, 200, 200);
-  fillrect(left_offset + (pos_x/32)*mini_tile_width, 0, 2, 15*4, 200, 200, 200, 200);
-  fillrect(left_offset + (pos_x/32)*mini_tile_width + 19*mini_tile_width - 2, 0, 2, 15*4, 200, 200, 200, 200);
-  fillrect(left_offset + (pos_x/32)*mini_tile_width, 15*4-2, 19*mini_tile_width, 2, 200, 200, 200, 200);
+  fillrect(left_offset + (pos_x/32)*mini_tile_width, 0, 19*mini_tile_width, 1, 255, 255, 255, 255);
+  fillrect(left_offset + (pos_x/32)*mini_tile_width, 0, 1, 15*4, 255, 255, 255, 255);
+  fillrect(left_offset + (pos_x/32)*mini_tile_width + 19*mini_tile_width, 0, 1, 15*4, 255, 255, 255, 255);
+  fillrect(left_offset + (pos_x/32)*mini_tile_width, 15*4-2, 19*mini_tile_width, 1, 255, 255, 255, 255);
 
 }
 
@@ -804,17 +804,17 @@ void le_drawinterface()
     }
   }
 
-  if(show_minimap) // use_gl because the minimap isn't shown correctly in software mode. Any idea? FIXME Possible reasons: SDL_SoftStretch is a hack itsself || an alpha blitting issue SDL can't handle in software mode
+  if(show_minimap)
     le_drawminimap();
 
   if(show_selections && MouseCursor::current() != mouse_select_object)
   {
-    if(le_selection_mode == CURSOR)
+    if(le_selection_mode == SM_CURSOR)
     {
       if(le_current.IsTile())
         le_selection->draw( cursor_x - pos_x, cursor_y);
     }
-    else if(le_selection_mode == SQUARE)
+    else if(le_selection_mode == SM_SQUARE)
     {
       int w, h;
       le_highlight_selection();
@@ -860,9 +860,9 @@ void le_drawinterface()
     le_next_level_bt->draw();
     le_previous_level_bt->draw();
     le_rubber_bt->draw();
-    if(le_selection_mode == SQUARE)
+    if(le_selection_mode == SM_SQUARE)
       le_select_mode_one_bt->draw();
-    else if(le_selection_mode == CURSOR)
+    else if(le_selection_mode == SM_CURSOR)
       le_select_mode_two_bt->draw();
     le_settings_bt->draw();
     le_move_right_bt->draw();
@@ -1305,17 +1305,17 @@ void le_checkevents()
           }
 
 
-          if(le_selection_mode == SQUARE)
+          if(le_selection_mode == SM_SQUARE)
           {
             le_select_mode_one_bt->event(event);
             if(le_select_mode_one_bt->get_state() == BUTTON_CLICKED)
-              le_selection_mode = CURSOR;
+              le_selection_mode = SM_CURSOR;
           }
           else
           {
             le_select_mode_two_bt->event(event);
             if(le_select_mode_two_bt->get_state() == BUTTON_CLICKED)
-              le_selection_mode = SQUARE;
+              le_selection_mode = SM_SQUARE;
           }
           ButtonPanelMap::iterator it;
           le_tilegroup_bt->event(event);
@@ -1574,6 +1574,8 @@ void le_checkevents()
       break;
     }
 
+  if(le_mouse_pressed[RIGHT])
+    show_minimap = true;
   }
 
 }
@@ -1623,7 +1625,7 @@ void le_change(float x, float y, int tm, unsigned int c)
 
     switch(le_selection_mode)
     {
-    case CURSOR:
+    case SM_CURSOR:
       le_world->get_level()->change(x,y,tm,c);
 
       base_type cursor_base;
@@ -1643,7 +1645,7 @@ void le_change(float x, float y, int tm, unsigned int c)
         }
 
       break;
-    case SQUARE:
+    case SM_SQUARE:
       if(selection.x1 < selection.x2)
       {
         x1 = selection.x1;
@@ -1724,7 +1726,7 @@ void le_showhelp()
 {
   bool tmp_show_grid = le_show_grid;
   int temp_le_selection_mode = le_selection_mode;
-  le_selection_mode = NONE;
+  le_selection_mode = SM_NONE;
   show_selections = true;
   le_show_grid = false;
   le_help_shown = true;
