@@ -1,4 +1,4 @@
-//  $Id: leveleditor.h,v 1.9 2004/05/09 13:55:54 rmcruz Exp $
+//  $Id: leveleditor.h,v 1.9.2.1 2004/05/15 22:22:54 sik0fewl Exp $
 // 
 //  SuperTux
 //  Copyright (C) 2003 Ricardo Cruz <rick2@aeiou.pt>
@@ -30,9 +30,9 @@ struct square
 
 /* selection modes */
 enum {
-  CURSOR,
-  SQUARE,
-  NONE
+  SM_CURSOR,
+  SM_SQUARE,
+  SM_NONE
 };
 
 int leveleditor(char* filename = NULL);
